@@ -567,7 +567,7 @@ class Game(object):
     def get_hands(self, nick):
         retVal = gr()
         hands = []
-        for p in sorted(self._players.keys()):
+        for p in self.turn_order:
             if self._players[p].name != nick:
                 hands.append(self._players[p].get_hand())
             else:
@@ -615,13 +615,9 @@ class Game(object):
                     table.append(self.markup.color(color.upper()[0] + nums, color))
 
         if not table:
-            ret.public.append(
-                self.markup.bold(
-                    self.markup.underline('Table: empty')))
+            ret.public.append(self.markup.underline('Table: empty'))
         else:
-            ret.public.append(
-                self.markup.bold(
-                    self.markup.underline('Table: %s' % ', '.join(table))))
+            ret.public.append(self.markup.underline('Table: %s' % ', '.join(table)))
 
         ret.public.append('Notes: %s, Storms: %s, %d cards remaining.' %
                          (''.join(sorted(self.notes)), ''.join(sorted(self.storms)), len(self.deck)))
